@@ -1,5 +1,5 @@
 
-from main import EzyVetApi
+from ezyvetapi.main import EzyVetApi
 from .models import *
 
 __all__ = ['models', 'main']
\ No newline at end of file
